@@ -1,4 +1,4 @@
-/* A Bison parser, made by GNU Bison 2.5.1.  */
+/* A Bison parser, made by GNU Bison 2.7.  */
 
 /* Bison implementation for Yacc-like parsers in C
    
@@ -44,7 +44,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.5.1"
+#define YYBISON_VERSION "2.7"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -58,19 +58,16 @@
 /* Pull parsers.  */
 #define YYPULL 1
 
-/* Using locations.  */
-#define YYLSP_NEEDED 1
 
 
 
 /* Copy the first part of user declarations.  */
-
-/* Line 268 of yacc.c  */
+/* Line 371 of yacc.c  */
 #line 1 "gram.y"
 
 /* This file is part of GDBM, the GNU data base manager.
-   Copyright (C) 1990, 1991, 1993, 2007, 2011, 2013,
-   2016 Free Software Foundation, Inc.
+   Copyright (C) 1990-1991, 1993, 2007, 2011, 2013, 2016-2018 Free
+   Software Foundation, Inc.
 
    GDBM is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -91,9 +88,8 @@
 struct dsegm *dsdef[DS_MAX];
   
 
-
-/* Line 268 of yacc.c  */
-#line 97 "gram.c"
+/* Line 371 of yacc.c  */
+#line 93 "gram.c"
 
 # ifndef YY_NULL
 #  if defined __cplusplus && 201103L <= __cplusplus
@@ -103,11 +99,6 @@ struct dsegm *dsdef[DS_MAX];
 #  endif
 # endif
 
-/* Enabling traces.  */
-#ifndef YYDEBUG
-# define YYDEBUG 1
-#endif
-
 /* Enabling verbose error messages.  */
 #ifdef YYERROR_VERBOSE
 # undef YYERROR_VERBOSE
@@ -116,11 +107,17 @@ struct dsegm *dsdef[DS_MAX];
 # define YYERROR_VERBOSE 1
 #endif
 
-/* Enabling the token table.  */
-#ifndef YYTOKEN_TABLE
-# define YYTOKEN_TABLE 0
+/* In a future release of Bison, this section will be replaced
+   by #include "y.tab.h".  */
+#ifndef YY_YY_GRAM_H_INCLUDED
+# define YY_YY_GRAM_H_INCLUDED
+/* Enabling traces.  */
+#ifndef YYDEBUG
+# define YYDEBUG 1
+#endif
+#if YYDEBUG
+extern int yydebug;
 #endif
-
 
 /* Tokens.  */
 #ifndef YYTOKENTYPE
@@ -156,12 +153,10 @@ struct dsegm *dsdef[DS_MAX];
 
 
 
-
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
 {
-
-/* Line 295 of yacc.c  */
+/* Line 387 of yacc.c  */
 #line 50 "gram.y"
 
   char *string;
@@ -177,9 +172,8 @@ typedef union YYSTYPE
   struct command *cmd;
 
 
-
-/* Line 295 of yacc.c  */
-#line 183 "gram.c"
+/* Line 387 of yacc.c  */
+#line 177 "gram.c"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
@@ -199,12 +193,28 @@ typedef struct YYLTYPE
 # define YYLTYPE_IS_TRIVIAL 1
 #endif
 
+extern YYSTYPE yylval;
+extern YYLTYPE yylloc;
+#ifdef YYPARSE_PARAM
+#if defined __STDC__ || defined __cplusplus
+int yyparse (void *YYPARSE_PARAM);
+#else
+int yyparse ();
+#endif
+#else /* ! YYPARSE_PARAM */
+#if defined __STDC__ || defined __cplusplus
+int yyparse (void);
+#else
+int yyparse ();
+#endif
+#endif /* ! YYPARSE_PARAM */
+
+#endif /* !YY_YY_GRAM_H_INCLUDED  */
 
 /* Copy the second part of user declarations.  */
 
-
-/* Line 345 of yacc.c  */
-#line 208 "gram.c"
+/* Line 390 of yacc.c  */
+#line 218 "gram.c"
 
 #ifdef short
 # undef short
@@ -257,24 +267,24 @@ typedef short int yytype_int16;
 # if defined YYENABLE_NLS && YYENABLE_NLS
 #  if ENABLE_NLS
 #   include <libintl.h> /* INFRINGES ON USER NAME SPACE */
-#   define YY_(msgid) dgettext ("bison-runtime", msgid)
+#   define YY_(Msgid) dgettext ("bison-runtime", Msgid)
 #  endif
 # endif
 # ifndef YY_
-#  define YY_(msgid) msgid
+#  define YY_(Msgid) Msgid
 # endif
 #endif
 
 /* Suppress unused-variable warnings by "using" E.  */
 #if ! defined lint || defined __GNUC__
-# define YYUSE(e) ((void) (e))
+# define YYUSE(E) ((void) (E))
 #else
-# define YYUSE(e) /* empty */
+# define YYUSE(E) /* empty */
 #endif
 
 /* Identity function, used to suppress warnings about constant conditions.  */
 #ifndef lint
-# define YYID(n) (n)
+# define YYID(N) (N)
 #else
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
@@ -520,7 +530,7 @@ static const yytype_uint16 yyrline[] =
 };
 #endif
 
-#if YYDEBUG || YYERROR_VERBOSE || YYTOKEN_TABLE
+#if YYDEBUG || YYERROR_VERBOSE || 1
 /* YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
    First, the terminals, then, starting at YYNTOKENS, nonterminals.  */
 static const char *const yytname[] =
@@ -629,10 +639,10 @@ static const yytype_int8 yytable[] =
       72,    74,    76,     0,    65,    62,    38,     0,    39
 };
 
-#define yypact_value_is_default(yystate) \
-  ((yystate) == (-11))
+#define yypact_value_is_default(Yystate) \
+  (!!((Yystate) == (-11)))
 
-#define yytable_value_is_error(yytable_value) \
+#define yytable_value_is_error(Yytable_value) \
   YYID (0)
 
 static const yytype_int8 yycheck[] =
@@ -704,7 +714,7 @@ do                                                              \
     }								\
 while (YYID (0))
 
-
+/* Error token number */
 #define YYTERROR	1
 #define YYERRCODE	256
 
@@ -713,27 +723,28 @@ while (YYID (0))
    If N is 0, then set CURRENT to the empty location which ends
    the previous symbol: RHS[0] (always defined).  */
 
-#define YYRHSLOC(Rhs, K) ((Rhs)[K])
 #ifndef YYLLOC_DEFAULT
-# define YYLLOC_DEFAULT(Current, Rhs, N)				\
-    do									\
-      if (YYID (N))                                                    \
-	{								\
-	  (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;	\
-	  (Current).first_column = YYRHSLOC (Rhs, 1).first_column;	\
-	  (Current).last_line    = YYRHSLOC (Rhs, N).last_line;		\
-	  (Current).last_column  = YYRHSLOC (Rhs, N).last_column;	\
-	}								\
-      else								\
-	{								\
-	  (Current).first_line   = (Current).last_line   =		\
-	    YYRHSLOC (Rhs, 0).last_line;				\
-	  (Current).first_column = (Current).last_column =		\
-	    YYRHSLOC (Rhs, 0).last_column;				\
-	}								\
+# define YYLLOC_DEFAULT(Current, Rhs, N)                                \
+    do                                                                  \
+      if (YYID (N))                                                     \
+        {                                                               \
+          (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;        \
+          (Current).first_column = YYRHSLOC (Rhs, 1).first_column;      \
+          (Current).last_line    = YYRHSLOC (Rhs, N).last_line;         \
+          (Current).last_column  = YYRHSLOC (Rhs, N).last_column;       \
+        }                                                               \
+      else                                                              \
+        {                                                               \
+          (Current).first_line   = (Current).last_line   =              \
+            YYRHSLOC (Rhs, 0).last_line;                                \
+          (Current).first_column = (Current).last_column =              \
+            YYRHSLOC (Rhs, 0).last_column;                              \
+        }                                                               \
     while (YYID (0))
 #endif
 
+#define YYRHSLOC(Rhs, K) ((Rhs)[K])
+
 
 /* YY_LOCATION_PRINT -- Print the location on the stream.
    This macro was not mandated originally: define only if we know
@@ -741,10 +752,46 @@ while (YYID (0))
 
 #ifndef YY_LOCATION_PRINT
 # if defined YYLTYPE_IS_TRIVIAL && YYLTYPE_IS_TRIVIAL
-#  define YY_LOCATION_PRINT(File, Loc)			\
-     fprintf (File, "%d.%d-%d.%d",			\
-	      (Loc).first_line, (Loc).first_column,	\
-	      (Loc).last_line,  (Loc).last_column)
+
+/* Print *YYLOCP on YYO.  Private, do not rely on its existence. */
+
+__attribute__((__unused__))
+#if (defined __STDC__ || defined __C99__FUNC__ \
+     || defined __cplusplus || defined _MSC_VER)
+static unsigned
+yy_location_print_ (FILE *yyo, YYLTYPE const * const yylocp)
+#else
+static unsigned
+yy_location_print_ (yyo, yylocp)
+    FILE *yyo;
+    YYLTYPE const * const yylocp;
+#endif
+{
+  unsigned res = 0;
+  int end_col = 0 != yylocp->last_column ? yylocp->last_column - 1 : 0;
+  if (0 <= yylocp->first_line)
+    {
+      res += fprintf (yyo, "%d", yylocp->first_line);
+      if (0 <= yylocp->first_column)
+        res += fprintf (yyo, ".%d", yylocp->first_column);
+    }
+  if (0 <= yylocp->last_line)
+    {
+      if (yylocp->first_line < yylocp->last_line)
+        {
+          res += fprintf (yyo, "-%d", yylocp->last_line);
+          if (0 <= end_col)
+            res += fprintf (yyo, ".%d", end_col);
+        }
+      else if (0 <= end_col && yylocp->first_column < end_col)
+        res += fprintf (yyo, "-%d", end_col);
+    }
+  return res;
+ }
+
+#  define YY_LOCATION_PRINT(File, Loc)          \
+  yy_location_print_ (File, &(Loc))
+
 # else
 #  define YY_LOCATION_PRINT(File, Loc) ((void) 0)
 # endif
@@ -752,7 +799,6 @@ while (YYID (0))
 
 
 /* YYLEX -- calling `yylex' with the right arguments.  */
-
 #ifdef YYLEX_PARAM
 # define YYLEX yylex (YYLEX_PARAM)
 #else
@@ -817,7 +863,7 @@ yy_symbol_value_print (yyoutput, yytype, yyvaluep, yylocationp)
   switch (yytype)
     {
       default:
-	break;
+        break;
     }
 }
 
@@ -1063,7 +1109,6 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
 {
   YYSIZE_T yysize0 = yytnamerr (YY_NULL, yytname[yytoken]);
   YYSIZE_T yysize = yysize0;
-  YYSIZE_T yysize1;
   enum { YYERROR_VERBOSE_ARGS_MAXIMUM = 5 };
   /* Internationalized format string. */
   const char *yyformat = YY_NULL;
@@ -1126,11 +1171,13 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
                     break;
                   }
                 yyarg[yycount++] = yytname[yyx];
-                yysize1 = yysize + yytnamerr (YY_NULL, yytname[yyx]);
-                if (! (yysize <= yysize1
-                       && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
-                  return 2;
-                yysize = yysize1;
+                {
+                  YYSIZE_T yysize1 = yysize + yytnamerr (YY_NULL, yytname[yyx]);
+                  if (! (yysize <= yysize1
+                         && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+                    return 2;
+                  yysize = yysize1;
+                }
               }
         }
     }
@@ -1150,10 +1197,12 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
 # undef YYCASE_
     }
 
-  yysize1 = yysize + yystrlen (yyformat);
-  if (! (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
-    return 2;
-  yysize = yysize1;
+  {
+    YYSIZE_T yysize1 = yysize + yystrlen (yyformat);
+    if (! (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+      return 2;
+    yysize = yysize1;
+  }
 
   if (*yymsg_alloc < yysize)
     {
@@ -1215,35 +1264,35 @@ yydestruct (yymsg, yytype, yyvaluep, yylocationp)
     {
 
       default:
-	break;
+        break;
     }
 }
 
 
-/* Prevent warnings from -Wmissing-prototypes.  */
-#ifdef YYPARSE_PARAM
-#if defined __STDC__ || defined __cplusplus
-int yyparse (void *YYPARSE_PARAM);
-#else
-int yyparse ();
-#endif
-#else /* ! YYPARSE_PARAM */
-#if defined __STDC__ || defined __cplusplus
-int yyparse (void);
-#else
-int yyparse ();
-#endif
-#endif /* ! YYPARSE_PARAM */
 
 
 /* The lookahead symbol.  */
 int yychar;
 
+
+#ifndef YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
+# define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
+# define YY_IGNORE_MAYBE_UNINITIALIZED_END
+#endif
+#ifndef YY_INITIAL_VALUE
+# define YY_INITIAL_VALUE(Value) /* Nothing. */
+#endif
+
 /* The semantic value of the lookahead symbol.  */
-YYSTYPE yylval;
+YYSTYPE yylval YY_INITIAL_VALUE(yyval_default);
 
 /* Location data for the lookahead symbol.  */
-YYLTYPE yylloc;
+YYLTYPE yylloc
+# if defined YYLTYPE_IS_TRIVIAL && YYLTYPE_IS_TRIVIAL
+  = { 1, 1, 1, 1 }
+# endif
+;
+
 
 /* Number of syntax errors so far.  */
 int yynerrs;
@@ -1310,7 +1359,7 @@ yyparse ()
   int yyn;
   int yyresult;
   /* Lookahead token as an internal (translated) token number.  */
-  int yytoken;
+  int yytoken = 0;
   /* The variables used to return semantic value and location from the
      action routines.  */
   YYSTYPE yyval;
@@ -1329,10 +1378,9 @@ yyparse ()
      Keep to zero when no symbol should be popped.  */
   int yylen = 0;
 
-  yytoken = 0;
-  yyss = yyssa;
-  yyvs = yyvsa;
-  yyls = yylsa;
+  yyssp = yyss = yyssa;
+  yyvsp = yyvs = yyvsa;
+  yylsp = yyls = yylsa;
   yystacksize = YYINITDEPTH;
 
   YYDPRINTF ((stderr, "Starting parse\n"));
@@ -1341,21 +1389,7 @@ yyparse ()
   yyerrstatus = 0;
   yynerrs = 0;
   yychar = YYEMPTY; /* Cause a token to be read.  */
-
-  /* Initialize stack pointers.
-     Waste one element of value and location stack
-     so that they stay on the same level as the state stack.
-     The wasted elements are never initialized.  */
-  yyssp = yyss;
-  yyvsp = yyvs;
-  yylsp = yyls;
-
-#if defined YYLTYPE_IS_TRIVIAL && YYLTYPE_IS_TRIVIAL
-  /* Initialize the default location before parsing starts.  */
-  yylloc.first_line   = yylloc.last_line   = 1;
-  yylloc.first_column = yylloc.last_column = 1;
-#endif
-
+  yylsp[0] = yylloc;
   goto yysetstate;
 
 /*------------------------------------------------------------.
@@ -1501,7 +1535,9 @@ yybackup:
   yychar = YYEMPTY;
 
   yystate = yyn;
+  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   *++yyvsp = yylval;
+  YY_IGNORE_MAYBE_UNINITIALIZED_END
   *++yylsp = yylloc;
   goto yynewstate;
 
@@ -1539,8 +1575,7 @@ yyreduce:
   switch (yyn)
     {
         case 6:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 75 "gram.y"
     {
 	      run_last_command ();
@@ -1548,8 +1583,7 @@ yyreduce:
     break;
 
   case 7:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 79 "gram.y"
     {
 	      if (run_command ((yyvsp[(1) - (3)].cmd), &(yyvsp[(2) - (3)].arglist)) && !interactive)
@@ -1558,8 +1592,7 @@ yyreduce:
     break;
 
   case 10:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 86 "gram.y"
     {
 	      if (interactive)
@@ -1573,15 +1606,13 @@ yyreduce:
     break;
 
   case 11:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 95 "gram.y"
     { end_def(); }
     break;
 
   case 12:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 96 "gram.y"
     {
 	      if (interactive)
@@ -1595,8 +1626,7 @@ yyreduce:
     break;
 
   case 13:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 108 "gram.y"
     {
 	      gdbmarglist_init (&(yyval.arglist), NULL);
@@ -1604,8 +1634,7 @@ yyreduce:
     break;
 
   case 15:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 115 "gram.y"
     {
 	      gdbmarglist_init (&(yyval.arglist), (yyvsp[(1) - (1)].arg));
@@ -1613,8 +1642,7 @@ yyreduce:
     break;
 
   case 16:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 119 "gram.y"
     {
 	      gdbmarglist_add (&(yyvsp[(1) - (2)].arglist), (yyvsp[(2) - (2)].arg));
@@ -1623,8 +1651,7 @@ yyreduce:
     break;
 
   case 17:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 126 "gram.y"
     {
 	      (yyval.arg) = gdbmarg_string ((yyvsp[(1) - (1)].string), &(yylsp[(1) - (1)]));
@@ -1632,8 +1659,7 @@ yyreduce:
     break;
 
   case 18:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 130 "gram.y"
     {
 	      (yyval.arg) = gdbmarg_kvpair ((yyvsp[(1) - (1)].kvpair), &(yylsp[(1) - (1)]));
@@ -1641,8 +1667,7 @@ yyreduce:
     break;
 
   case 19:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 136 "gram.y"
     {
 	      (yyval.kvpair) = (yyvsp[(2) - (3)].kvlist).head;
@@ -1650,8 +1675,7 @@ yyreduce:
     break;
 
   case 20:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 142 "gram.y"
     {
 	      (yyval.kvlist).head = (yyval.kvlist).tail = (yyvsp[(1) - (1)].kvpair);
@@ -1659,8 +1683,7 @@ yyreduce:
     break;
 
   case 21:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 146 "gram.y"
     {
 	      (yyvsp[(1) - (3)].kvlist).tail->next = (yyvsp[(3) - (3)].kvpair);
@@ -1670,8 +1693,7 @@ yyreduce:
     break;
 
   case 23:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 155 "gram.y"
     {
 	      (yyvsp[(3) - (3)].kvpair)->key = (yyvsp[(1) - (3)].string);
@@ -1680,8 +1702,7 @@ yyreduce:
     break;
 
   case 24:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 162 "gram.y"
     {
 	      (yyval.kvpair) = kvpair_string (&(yylsp[(1) - (1)]), (yyvsp[(1) - (1)].string));
@@ -1689,8 +1710,7 @@ yyreduce:
     break;
 
   case 25:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 166 "gram.y"
     {
 	      (yyval.kvpair) = kvpair_list (&(yylsp[(1) - (3)]), (yyvsp[(2) - (3)].slist).head);
@@ -1698,8 +1718,7 @@ yyreduce:
     break;
 
   case 26:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 172 "gram.y"
     {
 	      (yyval.slist).head = (yyval.slist).tail = slist_new_s ((yyvsp[(1) - (1)].string));
@@ -1707,8 +1726,7 @@ yyreduce:
     break;
 
   case 27:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 176 "gram.y"
     {
 	      struct slist *s = slist_new_s ((yyvsp[(3) - (3)].string));
@@ -1718,15 +1736,13 @@ yyreduce:
     break;
 
   case 30:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 187 "gram.y"
     { begin_def (); }
     break;
 
   case 31:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 188 "gram.y"
     {
 	      end_def ();
@@ -1736,8 +1752,7 @@ yyreduce:
     break;
 
   case 32:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 196 "gram.y"
     {
 	      (yyval.dsegm) = (yyvsp[(2) - (4)].dsegmlist).head;
@@ -1745,8 +1760,7 @@ yyreduce:
     break;
 
   case 33:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 200 "gram.y"
     {
 	      (yyval.dsegm) = dsegm_new_field ((yyvsp[(1) - (1)].type), NULL, 1);
@@ -1754,8 +1768,7 @@ yyreduce:
     break;
 
   case 36:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 210 "gram.y"
     {
 	      if (strcmp ((yyvsp[(1) - (1)].string), "key") == 0)
@@ -1772,8 +1785,7 @@ yyreduce:
     break;
 
   case 37:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 225 "gram.y"
     {
 	      (yyval.dsegmlist).head = (yyval.dsegmlist).tail = (yyvsp[(1) - (1)].dsegm);
@@ -1781,8 +1793,7 @@ yyreduce:
     break;
 
   case 38:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 229 "gram.y"
     {
 	      (yyvsp[(1) - (3)].dsegmlist).tail->next = (yyvsp[(3) - (3)].dsegm);
@@ -1792,8 +1803,7 @@ yyreduce:
     break;
 
   case 39:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 237 "gram.y"
     {
 	      (yyval.dsegm) = dsegm_new_field ((yyvsp[(1) - (2)].type), (yyvsp[(2) - (2)].string), 1);
@@ -1801,8 +1811,7 @@ yyreduce:
     break;
 
   case 40:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 241 "gram.y"
     {
 	      (yyval.dsegm) = dsegm_new_field ((yyvsp[(1) - (5)].type), (yyvsp[(2) - (5)].string), (yyvsp[(4) - (5)].num));
@@ -1810,8 +1819,7 @@ yyreduce:
     break;
 
   case 41:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 245 "gram.y"
     {
 	      (yyval.dsegm) = dsegm_new (FDEF_OFF);
@@ -1820,8 +1828,7 @@ yyreduce:
     break;
 
   case 42:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 250 "gram.y"
     {
 	      (yyval.dsegm) = dsegm_new (FDEF_PAD);
@@ -1830,8 +1837,7 @@ yyreduce:
     break;
 
   case 43:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 257 "gram.y"
     {
 	      variable_print_all (stdout);
@@ -1839,8 +1845,7 @@ yyreduce:
     break;
 
   case 48:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 269 "gram.y"
     {
 	      int t = 1;
@@ -1876,8 +1881,7 @@ yyreduce:
     break;
 
   case 49:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 301 "gram.y"
     {
 	      int rc = variable_set ((yyvsp[(1) - (3)].string), VART_STRING, (yyvsp[(3) - (3)].string));
@@ -1907,8 +1911,7 @@ yyreduce:
     break;
 
   case 52:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 333 "gram.y"
     {
 	      int rc = variable_unset ((yyvsp[(1) - (1)].string));
@@ -1930,9 +1933,8 @@ yyreduce:
     break;
 
 
-
-/* Line 1810 of yacc.c  */
-#line 1936 "gram.c"
+/* Line 1792 of yacc.c  */
+#line 1938 "gram.c"
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -2097,7 +2099,9 @@ yyerrlab1:
       YY_STACK_PRINT (yyss, yyssp);
     }
 
+  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   *++yyvsp = yylval;
+  YY_IGNORE_MAYBE_UNINITIALIZED_END
 
   yyerror_range[2] = yylloc;
   /* Using YYLLOC is tempting, but would change the location of
@@ -2168,8 +2172,7 @@ yyreturn:
 }
 
 
-
-/* Line 2071 of yacc.c  */
+/* Line 2055 of yacc.c  */
 #line 352 "gram.y"
 
 
@@ -2189,4 +2192,3 @@ yyerror (char const *s)
   terror ("%s", s);
   return 0;
 }
-
